package com.meas.system.domain;

import com.meas.common.annotation.Excel;
import com.meas.common.core.domain.BaseEntity;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.math.BigDecimal;

/**
 * 光谱辐射对象 meas_spectral_radiation
 *
 * @author wgk
 * @date 2024-06-13
 */
public class MeasSpectralRadiation extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 编号
     */
    private Long id;

    /**
     * 测量环境id
     */
    @Excel(name = "测量环境id")
    private Long measurementBatchId;

    /**
     * 发动机型号
     */
    private String engineModel;

    /**
     * 几何模型文件
     */
    private String geometryFiles;

    /**
     * 几何模型图片
     */
    private String geometryImage;

    /**
     * 测量批次
     */
    private String measurementBatch;

    /**
     * 发动机状态
     */
    private String engineStatus;

    /**
     * 角度
     */
    private String angle;

    /**
     * 型号
     */
    @Excel(name = "型号")
    private String model;

    /**
     * 镜头视场角
     */
    @Excel(name = "镜头视场角")
    private BigDecimal lensFView;

    /**
     * 增益
     */
    @Excel(name = "增益")
    private Long gain;

    /**
     * 背景数据
     */
    @Excel(name = "背景数据")
    private String backgroundData;

    /**
     * 标定温度
     */
    @Excel(name = "标定温度")
    private Long calTemp;

    /**
     * 标定曲线
     */
    @Excel(name = "标定曲线")
    private String calCurve;

    /**
     * 原始数据
     */
    @Excel(name = "原始数据")
    private String rawData;

    /**
     * 辐射亮度（3~5μm）
     */
    @Excel(name = "辐射亮度", readConverterExp = "3=~5μm")
    private String radiance1;

    /**
     * 辐射亮度（8~14μm）
     */
    @Excel(name = "辐射亮度", readConverterExp = "8=~14μm")
    private String radiance2;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getMeasurementBatchId() {
        return measurementBatchId;
    }

    public void setMeasurementBatchId(Long measurementBatchId) {
        this.measurementBatchId = measurementBatchId;
    }

    public String getEngineModel() {
        return engineModel;
    }

    public void setEngineModel(String engineModel) {
        this.engineModel = engineModel;
    }

    public String getGeometryFiles() {
        return geometryFiles;
    }

    public void setGeometryFiles(String geometryFiles) {
        this.geometryFiles = geometryFiles;
    }

    public String getGeometryImage() {
        return geometryImage;
    }

    public void setGeometryImage(String geometryImage) {
        this.geometryImage = geometryImage;
    }

    public String getMeasurementBatch() {
        return measurementBatch;
    }

    public void setMeasurementBatch(String measurementBatch) {
        this.measurementBatch = measurementBatch;
    }

    public String getEngineStatus() {
        return engineStatus;
    }

    public void setEngineStatus(String engineStatus) {
        this.engineStatus = engineStatus;
    }

    public String getAngle() {
        return angle;
    }

    public void setAngle(String angle) {
        this.angle = angle;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public BigDecimal getLensFView() {
        return lensFView;
    }

    public void setLensFView(BigDecimal lensFView) {
        this.lensFView = lensFView;
    }

    public Long getGain() {
        return gain;
    }

    public void setGain(Long gain) {
        this.gain = gain;
    }

    public String getBackgroundData() {
        return backgroundData;
    }

    public void setBackgroundData(String backgroundData) {
        this.backgroundData = backgroundData;
    }

    public Long getCalTemp() {
        return calTemp;
    }

    public void setCalTemp(Long calTemp) {
        this.calTemp = calTemp;
    }

    public String getCalCurve() {
        return calCurve;
    }

    public void setCalCurve(String calCurve) {
        this.calCurve = calCurve;
    }

    public String getRawData() {
        return rawData;
    }

    public void setRawData(String rawData) {
        this.rawData = rawData;
    }

    public String getRadiance1() {
        return radiance1;
    }

    public void setRadiance1(String radiance1) {
        this.radiance1 = radiance1;
    }

    public String getRadiance2() {
        return radiance2;
    }

    public void setRadiance2(String radiance2) {
        this.radiance2 = radiance2;
    }

    @Override
    public String toString() {
        return "MeasSpectralRadiation{" +
                "id=" + id +
                ", measurementBatchId=" + measurementBatchId +
                ", engineModel='" + engineModel + '\'' +
                ", geometryFiles='" + geometryFiles + '\'' +
                ", geometryImage='" + geometryImage + '\'' +
                ", measurementBatch='" + measurementBatch + '\'' +
                ", engineStatus='" + engineStatus + '\'' +
                ", angle='" + angle + '\'' +
                ", model='" + model + '\'' +
                ", lensFView=" + lensFView +
                ", gain=" + gain +
                ", backgroundData='" + backgroundData + '\'' +
                ", calTemp=" + calTemp +
                ", calCurve='" + calCurve + '\'' +
                ", rawData='" + rawData + '\'' +
                ", radiance1='" + radiance1 + '\'' +
                ", radiance2='" + radiance2 + '\'' +
                '}';
    }
}
